from strenum import StrEnum
import errno
import os
import subprocess


class DebRevision:
    def __init__(
            self,
            debianRevision: str,
            ubuntuRevision: str | None = None) -> None:
        self.DebianRevision = debianRevision
        self.UbuntuRevision = ubuntuRevision

    def __str__(self) -> str:
        if self.UbuntuRevision is None:
            return f"{self.DebianRevision}"
        else:
            return f"{self.DebianRevision}ubuntu{self.UbuntuRevision}"


class ChangelogEntryField(StrEnum):
    VERSION = "Version"
    DISTRIBUTION = "Distribution"
    URGENCY = "Urgency"
    MAINTAINER = "Maintainer"
    CHANGES = "Changes"


class Changelog:
    def __init__(self, path: str) -> None:
        if not os.path.exists(path):
            raise FileNotFoundError(
                errno.ENOENT, os.strerror(errno.ENOENT), path)

        self.Path = path

    def ParseFieldOfLatestEntry(self, field: ChangelogEntryField) -> str:
        field = subprocess.check_output(
            "dpkg-parsechangelog "
            f"--show-field {str(field.value)} "
            f"--file {self.Path}",
            text=True, shell=True)

        return field[:-1]  # remove trailing \n



#!/usr/bin/env python3

# Wrapper for compatiblity with older users of this repository. If you are a
# new user, look at using bin/turkey directly.
#
# We download a known-to-work prebuilt binary instead of compiling using the
# sourcecode ourselves.

import json
import os
import re
import sys
import subprocess
from urllib.request import urlopen


def download_turkey(binary):
    os.makedirs(os.path.dirname(binary), 0o755)
    release_url = "https://api.github.com/repos/redhat-developer/dotnet-bunny/releases/latest"
    with urlopen(release_url) as response:
        json_response = json.load(response)
        download_url = json_response['assets'][0]['browser_download_url']
        print('Downloading ' + download_url + ' to ' + binary)
        with urlopen(download_url) as download:
            with open(binary, 'wb') as f:
                f.write(download.read())
            os.chmod(binary, 0o755)

def main(args):
    binary = os.path.realpath(os.path.join('bin', 'turkey'))
    if not os.path.exists(binary):
        download_turkey(binary)

    p = subprocess.run([binary, '--version'], stdout=subprocess.PIPE, stderr=subprocess.STDOUT, universal_newlines=True, shell=False)
    print(p.stdout)
    if p.returncode != 0:
        return returncode

    test_args = []
    test_args.append(binary)
    # remove first two args
    # first arg is name of program
    # second arg is the .NET Core version
    test_args.extend(args[2:])
    test_args.append('-c')

    print('Running: ' + str(test_args))

    p = subprocess.run(test_args, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, universal_newlines=True, shell=False)
    print(p.stdout)
    if p.returncode != 0:
        return p.returncode

if __name__ == '__main__':
    sys.exit(main(sys.argv))



import re
from zlib import crc32

class _NameMangler:
    def words(self, name: str) -> str: ...
    def camel(self, name: str) -> str: ...
    def pascal(self, name: str) -> str: ...
    def kebab(self, name: str) -> str: ...
    def snake(self, name: str) -> str: ...
    def macro(self, name: str) -> str: ...
    def camel_snake(self, name: str) -> str: ...
    def pascal_snake(self, name: str) -> str: ...
    def spongebob(self, name: str) -> str: ...
    def cobol(self, name: str) -> str: ...
    def http_header(self, name: str) -> str: ...
